pub async fn execute_bash_once(
data: &PreparedBashScript,
ctx: &ExecutionContext,
) -> Result<RawExecutionResult>Expand description
Execute a single bash script inside a sandbox and return the result.
pub async fn execute_bash_once(
data: &PreparedBashScript,
ctx: &ExecutionContext,
) -> Result<RawExecutionResult>Execute a single bash script inside a sandbox and return the result.