Module sandbox

Module sandbox 

Functions

build_sandboxed_command
Build a Command that will execute script inside a sandbox.
sandbox_available
Returns true when a supported sandbox tool is available on this platform.
sandbox_tool_name
Human-readable name of the sandbox back-end for diagnostic messages.
validate_sandbox_cwd
Validate that a sandbox cwd does not contain path traversal via .. components.