pub struct BashSandboxTemplate {
pub network: Option<bool>,
pub writable_paths: Option<Vec<String>>,
pub max_time_ms: Option<u64>,
pub max_output_bytes: Option<u64>,
pub max_memory_bytes: Option<u64>,
pub max_cpu_time_ms: Option<u64>,
}Fields
network: Option<bool>writable_paths: Option<Vec<String>>max_time_ms: Option<u64>max_output_bytes: Option<u64>max_memory_bytes: Option<u64>max_cpu_time_ms: Option<u64>Trait Implementations
Sourceimpl Archive for BashSandboxTemplate
impl Archive for BashSandboxTemplate
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedBashSandboxTemplate
type Archived = ArchivedBashSandboxTemplate
The archived representation of this type. Read more
Sourcetype Resolver = BashSandboxTemplateResolver
type Resolver = BashSandboxTemplateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for BashSandboxTemplate
impl Clone for BashSandboxTemplate
Sourcefn clone(&self) -> BashSandboxTemplate
fn clone(&self) -> BashSandboxTemplate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BashSandboxTemplate
impl Debug for BashSandboxTemplate
Sourceimpl<'de> Deserialize<'de> for BashSandboxTemplate
impl<'de> Deserialize<'de> for BashSandboxTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<BashSandboxTemplate, __D> for Archived<BashSandboxTemplate>
impl<__D: Fallible + ?Sized> Deserialize<BashSandboxTemplate, __D> for Archived<BashSandboxTemplate>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<BashSandboxTemplate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<BashSandboxTemplate, <__D as Fallible>::Error>
Deserializes using the given deserializer